diff -r 8924f2174ac8 doc/model_tutorial.rst
--- a/doc/model_tutorial.rst	Wed Sep 08 20:29:05 2010 +0100
+++ b/doc/model_tutorial.rst	Thu Sep 09 10:24:09 2010 -0400
@@ -170,6 +170,38 @@
 value of ``'Bill'``, and ``age`` will be a float with a default value of
 ``10.0``.
 
+Care should be taken when overriding an attribute's setters and getters::
+
+    class ExampleModel(Model):
+
+        name = Str()
+
+        @name.getter
+        def name(self):
+            print('ExampleModel getter')
+
+        @name.setter
+        def name(self, value):
+            print('ExampleModel setter')
+
+
+    class SubModel(ExampleModel):
+
+        @ExampleModel.name.getter
+        def name(self):
+            print('SubModel getter')
+
+        @name.setter
+        def name(self, value):
+            print('SubModel setter')
+
+When overriding the "name" getter, "name" does not yet exist in the SubModel
+namespace, so the superclass "ExampleModel.name.getter" decorator must be
+used. As a result of overriding the "name" getter, "name" is defined in the
+SubModel namespace, so its decorators should be used for additional
+overrides. If the "ExampleModel.name.setter" decorator were used instead of
+"name.setter", the overridden "name" getter would be lost.
+
 
 Observing Attributes
 --------------------
@@ -190,39 +222,14 @@
 the subset of the collection that has been added.
 
 Note that if an observer has been called because a collection attribute has
-been rebound, then it is quite possible that 
+been rebound, then it is quite possible that
 :attr:`~dip.model.AttributeChange.old` and
 :attr:`~dip.model.AttributeChange.new` have values in common.
 
-The following example demonstrates one use of :func:`~dip.model.observe`::
-
-    from dip.model import Model, observe, Str
-
-
-    class ExampleModel(Model):
-
-        name = Str()
-
-
-    model = ExampleModel()
-
-    observe('name', model, lambda change: print("Value:", change.new))
-
-    model.name = 'First'
-    model.name = 'Second'
-
-Running this will cause the ``print()`` function to be called twice, once for
-each rebinding of ``model.name``.
-
-It is also possible to specify ``'*'`` as the name of the attribute to observe.
-This has the effect of observing all the attributes of the model.
-
-It is also possible to define a method to observe an attribute by decorating
+It is possible to define a method to observe an attribute by decorating
 it with the :meth:`~dip.model.ValueTypeFactory.observer` decorator.  The
 decorator is used just like the ``getter`` and ``setter`` decorators of
-standard Python properties.
-
-The following example is similar to the first but uses a decorated method::
+standard Python properties::
 
     from dip.model import Model, observe, Str
 
@@ -242,19 +249,28 @@
     model.name = 'First'
     model.name = 'Second'
 
+Running this will cause the ``print()`` function to be called twice, once for
+each rebinding of ``model.name``.
+
+Using an attribute type's :meth:`~dip.model.ValueTypeFactory.observer`
+decorator is convenient but has a couple of limitations:
+
+- only one attribute can be observed
+
+- the default connection type must be used.
+
+Using the :func:`~dip.model.observe` decorator avoids these limitations. For
+example, it is possible to specify ``'*'`` as the name of the attribute to
+observe. This has the effect of observing all the attributes of the model.
+Alternatively, a method can be decorated more than once in order to observe
+more than one attribute.
+
 :func:`~dip.model.observe` also accepts a ``type`` argument that is the
 :class:`~PyQt4.QtCore.Qt.ConnectionType` used when making the underlying
 Qt signal/slot connection.  It's default value is
 :attr:`~PyQt4.QtCore.Qt.AutoConnection`.
 
-Using a decorated method is very convenient but has a couple of limitations:
-
-- only one attribute can be observed
-
-- the default connection type must be used.
-
-Using :func:`~dip.model.observe` as a method decorator avoids all of these
-limitations::
+The following example uses the :func:`~dip.model.observe` decorator::
 
     from dip.model import Instance, Int, Model, observe, Str
 
@@ -266,7 +282,7 @@
         age = Int()
 
 
-    class Monitor(Model)
+    class Monitor(Model):
 
         example = Instance(ExampleModel)
 
@@ -288,6 +304,27 @@
     Value of 'name' is John
     Value of 'age' is 26
 
+:func:`~dip.model.observe` can also be used as a function::
+
+    from dip.model import Int, Model, observe, Str
+
+
+    class ExampleModel(Model):
+
+        name = Str()
+
+        age = Int()
+
+
+    model = ExampleModel()
+
+    observe('*', model,
+            lambda change:
+            print("Value of '{0}' is {1}".format(change.name, change.new)))
+
+    model.name = 'John'
+    model.age = 26
+
 
 Asynchronous Events
 -------------------
@@ -365,7 +402,7 @@
 
     @implements(IDownload)
     class Download(Model)
-    
+
         def download(self):
             """ Download the file using urllib. """
 
@@ -403,7 +440,7 @@
 
 
     class Download(AbstractDownload):
-    
+
         def download(self):
             """ Download the file using urllib. """
 